@@ -4,21 +4,25 @@ import numpy.typing
 
 
 @dataclass
-class DotPairMeasurement():
-	'''
+class DotPairMeasurement:
+	"""
 	Representation of a dot measuring oscillating dipoles.
 
 	Parameters
 	----------
 	v : float
-		The voltage measured at the dot.
+	The voltage measured at the dot.
+
 	r1 : numpy.ndarray
-		The position of the first dot.
+	The position of the first dot.
+
 	r2 : numpy.ndarray
-		The position of the second dot.
+	The position of the second dot.
+
 	f : float
-		The measurement frequency.
-	'''
+	The measurement frequency.
+	"""
+
 	v: float
 	r1: numpy.ndarray
 	r2: numpy.ndarray
@@ -30,23 +34,28 @@ class DotPairMeasurement():
 
 
 @dataclass
-class DotPairRangeMeasurement():
-	'''
+class DotPairRangeMeasurement:
+	"""
 	Representation of a dot measuring oscillating dipoles.
 
 	Parameters
 	----------
 	v_low : float
-		The lower range of voltage measured at the dot.
+	The lower range of voltage measured at the dot.
+
 	v_high : float
-		The upper range of voltage measured at the dot.
+	The upper range of voltage measured at the dot.
+
 	r1 : numpy.ndarray
-		The position of the first dot.
+	The position of the first dot.
+
 	r2 : numpy.ndarray
-		The position of the second dot.
+	The position of the second dot.
+
 	f : float
-		The measurement frequency.
-	'''
+	The measurement frequency.
+	"""
+
 	v_low: float
 	v_high: float
 	r1: numpy.ndarray
@@ -56,3 +65,5 @@ class DotPairRangeMeasurement():
 	def __post_init__(self) -> None:
 		self.r1 = numpy.array(self.r1)
 		self.r2 = numpy.array(self.r2)
+		if self.v_low > self.v_high:
+			self.v_low, self.v_high = self.v_high, self.v_low
