@@ -4,21 +4,37 @@ from dataclasses import dataclass
 from typing import Sequence, Tuple
 import scipy.optimize
 from pdme.model.model import Model, Discretisation
-from pdme.measurement import DotMeasurement, OscillatingDipoleArrangement, OscillatingDipole
+from pdme.measurement import (
+	DotMeasurement,
+	OscillatingDipoleArrangement,
+	OscillatingDipole,
+)
 
 
 class FixedDipoleModel(Model):
-	'''
+	"""
 	Model of oscillating dipole with a fixed dipole moment.
 
 	Parameters
 	----------
 	p : numpy.ndarray
-		The fixed dipole moment.
+	The fixed dipole moment.
+
 	n : int
-		The number of dipoles to assume.
-	'''
-	def __init__(self, xmin: float, xmax: float, ymin: float, ymax: float, zmin: float, zmax: float, p: numpy.ndarray, n: int) -> None:
+	The number of dipoles to assume.
+	"""
+
+	def __init__(
+		self,
+		xmin: float,
+		xmax: float,
+		ymin: float,
+		ymax: float,
+		zmin: float,
+		zmax: float,
+		p: numpy.ndarray,
+		n: int,
+	) -> None:
 		self.xmin = xmin
 		self.xmax = xmax
 		self.ymin = ymin
@@ -30,12 +46,20 @@ class FixedDipoleModel(Model):
 		self.rng = numpy.random.default_rng()
 
 	def __repr__(self) -> str:
-		return f'FixedDipoleModel({self.xmin}, {self.xmax}, {self.ymin}, {self.ymax}, {self.zmin}, {self.zmax}, {self.p}, {self.n()})'
+		return f"FixedDipoleModel({self.xmin}, {self.xmax}, {self.ymin}, {self.ymax}, {self.zmin}, {self.zmax}, {self.p}, {self.n()})"
 
 	# TODO: this signature doesn't make sense.
 	def get_dipoles(self, frequency: float) -> OscillatingDipoleArrangement:
-		s_pts = numpy.array((self.rng.uniform(self.xmin, self.xmax), self.rng.uniform(self.ymin, self.ymax), self.rng.uniform(self.zmin, self.zmax)))
-		return OscillatingDipoleArrangement([OscillatingDipole(self.p, s_pts, frequency)])
+		s_pts = numpy.array(
+			(
+				self.rng.uniform(self.xmin, self.xmax),
+				self.rng.uniform(self.ymin, self.ymax),
+				self.rng.uniform(self.zmin, self.zmax),
+			)
+		)
+		return OscillatingDipoleArrangement(
+			[OscillatingDipole(self.p, s_pts, frequency)]
+		)
 
 	def solution_single_dipole(self, pt: numpy.ndarray) -> OscillatingDipole:
 		# assume length is 4.
@@ -44,10 +68,10 @@ class FixedDipoleModel(Model):
 		return OscillatingDipole(self.p, s, w)
 
 	def point_length(self) -> int:
-		'''
-			Dipole is constrained magnitude, but free orientation.
-			Six degrees of freedom: (sx, sy, sz, w).
-		'''
+		"""
+		Dipole is constrained magnitude, but free orientation.
+		Six degrees of freedom: (sx, sy, sz, w).
+		"""
 		return 4
 
 	def n(self) -> int:
@@ -58,45 +82,59 @@ class FixedDipoleModel(Model):
 		w = pt[3]
 
 		diff = dot.r - s
-		alpha = self.p.dot(diff) / (numpy.linalg.norm(diff)**3)
+		alpha = self.p.dot(diff) / (numpy.linalg.norm(diff) ** 3)
 		b = (1 / numpy.pi) * (w / (w**2 + dot.f**2))
 		return alpha**2 * b
 
-	def jac_for_point_at_dot(self, dot: DotMeasurement, pt: numpy.ndarray) -> numpy.ndarray:
+	def jac_for_point_at_dot(
+		self, dot: DotMeasurement, pt: numpy.ndarray
+	) -> numpy.ndarray:
 		s = pt[0:3]
 		w = pt[3]
 
 		diff = dot.r - s
-		alpha = self.p.dot(diff) / (numpy.linalg.norm(diff)**3)
+		alpha = self.p.dot(diff) / (numpy.linalg.norm(diff) ** 3)
 		b = (1 / numpy.pi) * (w / (w**2 + dot.f**2))
 
-		r_divs = (-self.p / (numpy.linalg.norm(diff)**3) + 3 * self.p.dot(diff) * diff / (numpy.linalg.norm(diff)**5)) * 2 * alpha * b
+		r_divs = (
+			(
+				-self.p / (numpy.linalg.norm(diff) ** 3)
+				+ 3 * self.p.dot(diff) * diff / (numpy.linalg.norm(diff) ** 5)
+			)
+			* 2
+			* alpha
+			* b
+		)
 
 		f2 = dot.f**2
 		w2 = w**2
 
-		w_div = alpha**2 * (1 / numpy.pi) * ((f2 - w2) / ((f2 + w2)**2))
+		w_div = alpha**2 * (1 / numpy.pi) * ((f2 - w2) / ((f2 + w2) ** 2))
 
 		return numpy.concatenate((r_divs, w_div), axis=None)
 
 
 @dataclass
 class FixedDipoleDiscretisation(Discretisation):
-	'''
+	"""
 	Representation of a discretisation of a FixedDipoleDiscretisation.
 	Also captures a rough maximum value of dipole.
 
 	Parameters
 	----------
 	model : FixedDipoleModel
-		The parent model of the discretisation.
+	The parent model of the discretisation.
+
 	num_x : int
-		The number of partitions of the x axis.
+	The number of partitions of the x axis.
+
 	num_y : int
-		The number of partitions of the y axis.
+	The number of partitions of the y axis.
+
 	num_z : int
-		The number of partitions of the z axis.
-	'''
+	The number of partitions of the z axis.
+	"""
+
 	model: FixedDipoleModel
 	num_x: int
 	num_y: int
@@ -115,22 +153,32 @@ class FixedDipoleDiscretisation(Discretisation):
 		# We want to keep w unbounded, restrict sx, sy, sz, px and py based on step.
 		return (
 			[
-				xi * self.x_step + self.model.xmin, yi * self.y_step + self.model.ymin, zi * self.z_step + self.model.zmin,
-				-numpy.inf
+				xi * self.x_step + self.model.xmin,
+				yi * self.y_step + self.model.ymin,
+				zi * self.z_step + self.model.zmin,
+				-numpy.inf,
 			],
 			[
-				(xi + 1) * self.x_step + self.model.xmin, (yi + 1) * self.y_step + self.model.ymin, (zi + 1) * self.z_step + self.model.zmin,
-				numpy.inf
-			]
+				(xi + 1) * self.x_step + self.model.xmin,
+				(yi + 1) * self.y_step + self.model.ymin,
+				(zi + 1) * self.z_step + self.model.zmin,
+				numpy.inf,
+			],
 		)
 
 	def all_indices(self) -> numpy.ndindex:
 		# see https://github.com/numpy/numpy/issues/20706 for why this is a mypy problem.
 		return numpy.ndindex((self.num_x, self.num_y, self.num_z))  # type:ignore
 
-	def solve_for_index(self, dots: Sequence[DotMeasurement], index: Tuple[float, ...]) -> scipy.optimize.OptimizeResult:
+	def solve_for_index(
+		self, dots: Sequence[DotMeasurement], index: Tuple[float, ...]
+	) -> scipy.optimize.OptimizeResult:
 		bounds = self.bounds(index)
 		sx_mean = (bounds[0][0] + bounds[1][0]) / 2
 		sy_mean = (bounds[0][1] + bounds[1][1]) / 2
 		sz_mean = (bounds[0][2] + bounds[1][2]) / 2
-		return self.model.solve(dots, initial_pt=numpy.array([sx_mean, sy_mean, sz_mean, .1]), bounds=bounds)
+		return self.model.solve(
+			dots,
+			initial_pt=numpy.array([sx_mean, sy_mean, sz_mean, 0.1]),
+			bounds=bounds,
+		)
