@@ -26,7 +26,20 @@ def flip_chunk_to_positive_px(pt: numpy.ndarray) -> numpy.ndarray:
 
 
 def normalise_point_list(pts: numpy.ndarray, pt_length) -> numpy.ndarray:
-	chunked_pts = [flip_chunk_to_positive_px(pts[i: i + pt_length]) for i in range(0, len(pts), pt_length)]
+	chunked_pts = [
+		flip_chunk_to_positive_px(pts[i : i + pt_length])
+		for i in range(0, len(pts), pt_length)
+	]
 	range_to_length = list(range(pt_length))
-	rotated_range = range_to_length[pt_length - 1:] + range_to_length[0:pt_length - 1]
-	return numpy.concatenate(sorted(chunked_pts, key=lambda x: tuple(round(val, 3) for val in operator.itemgetter(*rotated_range)(x))), axis=None)
+	rotated_range = (
+		range_to_length[pt_length - 1 :] + range_to_length[0 : pt_length - 1]
+	)
+	return numpy.concatenate(
+		sorted(
+			chunked_pts,
+			key=lambda x: tuple(
+				round(val, 3) for val in operator.itemgetter(*rotated_range)(x)
+			),
+		),
+		axis=None,
+	)
